recognizer package
==================

Submodules
----------

recognizer.cli module
---------------------

.. automodule:: recognizer.cli
    :members:
    :undoc-members:
    :show-inheritance:

recognizer.recognizer module
----------------------------

.. automodule:: recognizer.recognizer
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: recognizer
    :members:
    :undoc-members:
    :show-inheritance:
